@@ -12,8 +12,7 @@ class LogicalVolumeFilter(NetBoxModelFilterSet):
             "vg",
             "lv_name",
             "size",
-            "device",
-            "description",
+            "description"
         ]
 
     def search(self, queryset, name, value):
