@@ -99,13 +99,7 @@ class DriveCreateForm(NetBoxModelForm):
             "size",
             "cluster",
             "description",
-            'content_type',
-            'object_id',
         )
-        widgets = {
-            'content_type': HiddenInput(),
-            'object_id': HiddenInput(),
-        }
 
     def save(self, *args, **kwargs):
         if self.cleaned_data['virtual_machine']:
@@ -117,6 +111,8 @@ class DriveCreateForm(NetBoxModelForm):
 
         number_of_drives = Drive.objects.filter(object_id=parent_object_pk, content_type_id=parent_object_type).count() or 0
         self.instance.identifier = f'Hard Drive {number_of_drives + 1}'
+        self.instance.object_id = parent_object_pk
+        self.instance.content_type_id = parent_object_type
         drive = super().save(*args, **kwargs)
 
         if self.cleaned_data['platform'] and 'windows' not in str(self.cleaned_data['platform']).lower():
