@@ -21,6 +21,10 @@ class DriveTable(NetBoxTable):
     cluster = tables.Column(
         linkify=True
     )
+    object = tables.Column(
+        linkify=True,
+        verbose_name="Parent Object"
+    )
 
     class Meta(NetBoxTable.Meta):
         model = Drive
